@@ -4,7 +4,8 @@ use vl_convert_rs::{VlConverter, VlVersion};
 async fn main() {
     let mut converter = VlConverter::new();
 
-    let vl_spec: serde_json::Value = serde_json::from_str(r#"
+    let vl_spec: serde_json::Value = serde_json::from_str(
+        r#"
 {
   "$schema": "https://vega.github.io/schema/vega-lite/v5.json",
   "data": {"url": "data/movies.json"},
@@ -20,11 +21,14 @@ async fn main() {
     },
     "size": {"aggregate": "count"}
   }
-}   "#).unwrap();
+}   "#,
+    )
+    .unwrap();
 
-    let vega_spec = converter.vegalite_to_vega(vl_spec, VlVersion::v5_5, true).await.expect(
-        "Failed to perform Vega-Lite to Vega conversion"
-    );
+    let vega_spec = converter
+        .vegalite_to_vega(vl_spec, VlVersion::v5_5, true)
+        .await
+        .expect("Failed to perform Vega-Lite to Vega conversion");
 
     println!("{}", vega_spec)
 }
